from flask import Flask # https://www.palletsprojects.com/p/flask/
from flask_sqlalchemy import SQLAlchemy # https://flask-sqlalchemy.palletsprojects.com/en/2.x/
from flask_login import LoginManager, UserMixin # https://flask-login.readthedocs.io/en/latest/
import os

# from https://flask.palletsprojects.com/en/1.1.x/quickstart/
app = Flask(__name__) # instancia triedy Flask
# flask pouziva na autentifikaciu pouzivatelov session
# na podpisovanie session cookies musi byt nastaveny kluc
app.secret_key = os.urandom(16)
app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///cars.db' # databaza
# from https://flask-sqlalchemy.palletsprojects.com/en/2.x/quickstart/
db = SQLAlchemy(app) # vytvorenie objektu SQLAlchemy
# trieda User
# dedi od UserMixin - implementacia zakladnych metod charakteristickych pre pouzivatela a db.Model
class User(UserMixin,db.Model):
    id = db.Column(db.Integer,primary_key = True)
    email = db.Column(db.String(100),unique = True)
    password = db.Column(db.String(100))
# instancia triedy LoginManager
logman = LoginManager()
logman.init_app(app) # previazanie flask_login s flask
logman.login_view = 'auth_page.login' # neautentifikovany pouzivatel bude presmerovany tu
# from https://flask-login.readthedocs.io/en/latest/#how-it-works
# session user object callback
@logman.user_loader
def load_user(user_id):
   return User.query.get(int(user_id))
# from https://flask.palletsprojects.com/en/1.0.x/blueprints/
# blueprint - funguje podobne ako aplikacia ale nie je to aplikacia
#           - delia aplikaciu na mensie casti
#           - zdielaju konfiguraciu aplikacie
# blueprint - neautentifikovany pouzivatel URL /
from .outer import outer
app.register_blueprint(outer)
# blueprint - autentifikacia pouzivatela URL /register /otp /login /logout
from .auth import auth
app.register_blueprint(auth)
# blueprint - autentifikovany pouzivatel URL /inside
from .inner import inner
app.register_blueprint(inner)
